@@ -32,7 +32,7 @@ SYSVLEVELS="2 3 4 5"
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux-64-3.1.11004-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux-64-4.1.06020-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect Secure Mobility Client"
 FEEDBACK_DIR="${INSTPREFIX}/CustomerExperienceFeedback"
 
@@ -234,7 +234,7 @@ if [ -f "${NEWTEMP}/libvpnipsec.so" ]; then
     ${INSTALL} -o root -m 755 ${NEWTEMP}/libvpnipsec.so ${PLUGINDIR} || exit 1
 else
     echo "${NEWTEMP}/libvpnipsec.so does not exist. It will not be installed."
-fi 
+fi
 
 if [ -f "${NEWTEMP}/libacfeedback.so" ]; then
     echo "Installing "${NEWTEMP}/libacfeedback.so >> /tmp/${LOGFNAME}
@@ -360,6 +360,9 @@ else
     echo "${NEWTEMP}/vpndownloader-cli does not exist. It will not be installed."
 fi
 
+echo "Installing "${NEWTEMP}/acinstallhelper >> /tmp/${LOGFNAME}
+${INSTALL} -o root -m 755 ${NEWTEMP}/acinstallhelper ${BINDIR} || exit 1
+
 
 # Open source information
 echo "Installing "${NEWTEMP}/OpenSource.html >> /tmp/${LOGFNAME}
@@ -372,10 +375,8 @@ ${INSTALL} -o root -m 444 ${NEWTEMP}/AnyConnectProfile.xsd ${PROFILEDIR} || exit
 echo "Installing "${NEWTEMP}/AnyConnectLocalPolicy.xsd >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 444 ${NEWTEMP}/AnyConnectLocalPolicy.xsd ${INSTPREFIX} || exit 1
 
-# Import any AnyConnect XML profiles side by side vpn install directory (in well known Profiles/vpn directory)
-# Also import the AnyConnectLocalPolicy.xml file (if present)
-# If failure occurs here then no big deal, don't exit with error code
-# only copy these files if tempdir is . which indicates predeploy
+# Import any AnyConnect XML profiles and read the ACTransforms.xml
+# Errors that occur during import are intentionally ignored (best effort)
 
 INSTALLER_FILE_DIR=$(dirname "$0")
 
@@ -412,8 +413,26 @@ getProperty()
     echo $TAG_FROM_FILE;
 }
 
+DISABLE_VPN_TAG="DisableVPN"
 DISABLE_FEEDBACK_TAG="DisableCustomerExperienceFeedback"
 
+BYPASS_DOWNLOADER_TAG="BypassDownloader"
+FIPS_MODE_TAG="FipsMode"
+RESTRICT_PREFERENCE_CACHING_TAG="RestrictPreferenceCaching"
+RESTRICT_TUNNEL_PROTOCOLS_TAG="RestrictTunnelProtocols"
+RESTRICT_WEB_LAUNCH_TAG="RestrictWebLaunch"
+STRICT_CERTIFICATE_TRUST_TAG="StrictCertificateTrust"
+EXCLUDE_PEM_FILE_CERT_STORE_TAG="ExcludePemFileCertStore"
+EXCLUDE_WIN_NATIVE_CERT_STORE_TAG="ExcludeWinNativeCertStore"
+EXCLUDE_MAC_NATIVE_CERT_STORE_TAG="ExcludeMacNativeCertStore"
+EXCLUDE_FIREFOX_NSS_CERT_STORE_TAG="ExcludeFirefoxNSSCertStore"
+ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER_TAG="AllowSoftwareUpdatesFromAnyServer"
+ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER_TAG="AllowComplianceModuleUpdatesFromAnyServer"
+ALLOW_VPN_PROFILE_UPDATES_FROM_ANY_SERVER_TAG="AllowVPNProfileUpdatesFromAnyServer"
+ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG="AllowISEProfileUpdatesFromAnyServer"
+ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG="AllowServiceProfileUpdatesFromAnyServer"
+AUTHORIZED_SERVER_LIST_TAG="AuthorizedServerList"
+
 if $IS_PRE_DEPLOY; then
     if [ -d "${PROFILE_IMPORT_DIR}" ]; then
         TRANSFORM_FILE="${PROFILE_IMPORT_DIR}/ACTransforms.xml"
@@ -422,10 +441,27 @@ else
     TRANSFORM_FILE="${INSTALLER_FILE_DIR}/ACTransforms.xml"
 fi
 
-#get the tag values from the transform file  
 if [ -f "${TRANSFORM_FILE}" ] ; then
     echo "Processing transform file in ${TRANSFORM_FILE}"
+    DISABLE_VPN=$(getProperty "${TRANSFORM_FILE}" ${DISABLE_VPN_TAG})
     DISABLE_FEEDBACK=$(getProperty "${TRANSFORM_FILE}" ${DISABLE_FEEDBACK_TAG} "true" )
+
+    BYPASS_DOWNLOADER=$(getProperty "${TRANSFORM_FILE}" ${BYPASS_DOWNLOADER_TAG})
+    FIPS_MODE=$(getProperty "${TRANSFORM_FILE}" ${FIPS_MODE_TAG})
+    RESTRICT_PREFERENCE_CACHING=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_PREFERENCE_CACHING_TAG})
+    RESTRICT_TUNNEL_PROTOCOLS=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_TUNNEL_PROTOCOLS_TAG})
+    RESTRICT_WEB_LAUNCH=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_WEB_LAUNCH_TAG})
+    STRICT_CERTIFICATE_TRUST=$(getProperty "${TRANSFORM_FILE}" ${STRICT_CERTIFICATE_TRUST_TAG})
+    EXCLUDE_PEM_FILE_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_PEM_FILE_CERT_STORE_TAG})
+    EXCLUDE_WIN_NATIVE_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_WIN_NATIVE_CERT_STORE_TAG})
+    EXCLUDE_MAC_NATIVE_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_MAC_NATIVE_CERT_STORE_TAG})
+    EXCLUDE_FIREFOX_NSS_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_FIREFOX_NSS_CERT_STORE_TAG})
+    ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_VPN_PROFILE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_VPN_PROFILE_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG})
+    AUTHORIZED_SERVER_LIST=$(getProperty "${TRANSFORM_FILE}" ${AUTHORIZED_SERVER_LIST_TAG})
 fi
 
 # if disable phone home is specified, remove the phone home plugin and any data folder
@@ -438,6 +474,23 @@ if [ "x${DISABLE_FEEDBACK}" = "xtrue" ] ; then
     rm -rf ${FEEDBACK_DIR}
 fi
 
+# generate default AnyConnect Local Policy file if it doesn't already exist
+${BINDIR}/acinstallhelper -acpolgen bd=${BYPASS_DOWNLOADER:-false} \
+                                    fm=${FIPS_MODE:-false} \
+                                    rpc=${RESTRICT_PREFERENCE_CACHING:-false} \
+                                    rtp=${RESTRICT_TUNNEL_PROTOCOLS:-false} \
+                                    rwl=${RESTRICT_WEB_LAUNCH:-false} \
+                                    sct=${STRICT_CERTIFICATE_TRUST:-false} \
+                                    epf=${EXCLUDE_PEM_FILE_CERT_STORE:-false} \
+                                    ewn=${EXCLUDE_WIN_NATIVE_CERT_STORE:-false} \
+                                    emn=${EXCLUDE_MAC_NATIVE_CERT_STORE:-false} \
+                                    efn=${EXCLUDE_FIREFOX_NSS_CERT_STORE:-false} \
+                                    upsu=${ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER:-true} \
+                                    upcu=${ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER:-true} \
+                                    upvp=${ALLOW_VPN_PROFILE_UPDATES_FROM_ANY_SERVER:-true} \
+                                    upip=${ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER:-true} \
+                                    upsp=${ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER:-true} \
+                                    upal=${AUTHORIZED_SERVER_LIST}
 
 # Attempt to install the init script in the proper place
 
